      PROGRAM MAKE_NBS
c****************************************************************************
c  
c  AUTHOR:   Tim Hunter     3/20/91  (early development version)
c  REVISED:  MIKE O'CONNOR  5/03/94  (major revision)
c            Tim Hunter     7/20/94  (significant cleanup and documentation)
c            Tim Hunter     1/04/95  (Note about Ogoki in header)
c
c  PURPOSE:  This program reads the monthly precip, runoff, and evap from the 
c            respective overlake files and combines them to compute the
c            overlake net basin supply.  It writes the NBS values into output
c            file, with unit of measure (cubic cms/second).
c            The input files are in centimeters over the lake.
c
c****************************************************************************
      IMPLICIT    NONE
      INTEGER     SYr, EYr 
      PARAMETER   (SYr = 1948)
      PARAMETER   (EYr = 1999)

      INTEGER     CompMethod, ResidMethod
      PARAMETER   (CompMethod  = 1)
      PARAMETER   (ResidMethod = 2)

      INTEGER     OverLake, OverLand
      PARAMETER   (OverLake = 1)
      PARAMETER   (OverLand = 2)

      INTEGER     Centimeters, CubicMeters
      PARAMETER   (Centimeters = 1)
      PARAMETER   (CubicMeters = 2)


      INTEGER     Method, PrcType, Units, LakeNum, NameLen, Ogoki,
     &            StartYr, EndYr
      INTEGER     LengthName(7) 
      REAL*4      LkArea, LakeAreas(7)
      CHARACTER*1 Answer
      CHARACTER*3 Bsn
      CHARACTER*8 LakeName, Lakes(7)


      DATA LengthName /8, 8, 5, 7, 4, 7, 8/
      DATA Lakes /'Superior', 'Michigan', 'Huron   ', 
     &            'StClair ', 'Erie    ', 'Ontario ',
     &            'Mich-Hur'/
      DATA LakeAreas / 0.8210e+11, 0.5780e+11, 0.5960e+11, 
     &                 0.1114e+10, 0.2570e+11, 1.8960e+10, 
     &                 1.1740e+11 /

      COMMON /Options/ PrcType, Units, LakeName, NameLen, Ogoki,
     &                 StartYr, EndYr


c
c  The statement label 5 is simply a place marker for restarting the
c  process.  It is accessed by a GOTO statement at the end of the main
c  program.  I could have eliminated it with a DO WHILE but this seems
c  cleaner to me since it is a single GOTO and does not confuse the
c  issue of program execution (i.e. tracing program flow is easy)
c
  5   CONTINUE

c
c  Initialize 
c
      StartYr = 1950
      EndYr   = EYr
      Ogoki   = -1

c
c Choose the method to be used for computing the Net Basin Supply.
c   If the user chooses "tenths of mellimeters" we will call that
c   "centimeters" throughout the program because that's originally
c   what the program was asking the user and I don't want to change 
c   the whole program code and documentation.  We'll just remember 
c   that it really means tenths of mm.  It only affects the header
c   and the write statement to the output file.
c  
      CALL GetMethod(Method)

c
c  Get lake name and assign values based on the lake
c
      CALL GetLakeName(LakeNum, Method)

      LakeName = Lakes(LakeNum)
      Bsn = LakeName(1:3)
      CALL Caps(Bsn, 3)
      IF (LakeNum .EQ. 7) Bsn = 'M-H'
      NameLen = LengthName(LakeNum)
      LkArea = LakeAreas(LakeNum)

c
c Choose the precipitation type (overland/overlake) only if using
c the component method
c
      IF (Method .EQ. CompMethod) CALL GetPrcType(PrcType)

c
c Choose the units of measurement for output file.
c
      CALL GetOutputUnits(Units)

c
c If we are doing Lake Superior and using the residual method, then we
c need to know whether or not to include the Ogoki Diversion in the
c inflow (See tech memo for more info)
c
      IF ((LakeName .EQ. 'Superior') .AND. (Method .EQ. ResidMethod))
     &   CALL GetOgoki(Ogoki)

c
c Since the Welland Canal file only extends through 1989, set the end
c year appropriately for Erie or Ontario if doing residual method
c
      IF (Method .EQ. ResidMethod) THEN
        IF (LakeName .EQ. 'Erie    ') EndYr = 1989
        IF (LakeName .EQ. 'Ontario ') EndYr = 1989
      ENDIF

c
c  Open output file.
c
      IF (Method .EQ. CompMethod) THEN
        OPEN(UNIT=25, FILE='COMPNBS.'//Bsn, STATUS='OLD', ERR=15)
        CLOSE(25, STATUS='DELETE')
  15    OPEN(UNIT=25, FILE='COMPNBS.'//Bsn, STATUS='NEW')
      ELSE
        OPEN(UNIT=25, FILE='RESIDNBS.'//Bsn, STATUS='OLD', ERR=16)
        CLOSE(25, STATUS='DELETE')
  16    OPEN(UNIT=25, FILE='RESIDNBS.'//Bsn, STATUS='NEW')
      ENDIF

c
c  Write header into output file
c
c  If we are processing Lake Superior (component method) we will
c  put in a note that Ogoki is included.  Otherwise the second
c  header line is blank. If we are processing Lake Superior with
c  the residual method then we will conditionally put in that note
c  dependant on the status of the user's choice regarding Ogoki.
c
      IF (Method .EQ. CompMethod) THEN

        IF (PrcType .EQ. OverLake) THEN
          IF (Units .EQ. Centimeters) THEN
             WRITE(25,2500) LakeName
          ELSE
             WRITE(25,2510) LakeName
          ENDIF
        ELSE
          IF (Units .EQ. Centimeters) THEN
             WRITE(25,2700) LakeName
          ELSE
             WRITE(25,2710) LakeName
          ENDIF
        ENDIF
        IF (LakeNum .EQ. 1) THEN
           WRITE(25, 3000)
           WRITE(*,*) ' NOTE!!! The Ogoki diversion IS INCLUDED!'
           WRITE(*,*) CHAR(7),CHAR(7),CHAR(7)
        ELSE
           WRITE(25,2200)
        ENDIF
        WRITE(25,2401)
        WRITE(25,2411)

      ELSE      ! (Method .EQ. ResidMethod)

        IF (Units .EQ. Centimeters) THEN
          WRITE(25,2600) LakeName
          IF (LakeNum .EQ. 1) THEN
            IF (Ogoki .EQ. 1) THEN
              WRITE(25,3000)
            ELSE
              WRITE(25,3005)
            ENDIF
          ELSE
            WRITE(25,2200)
          ENDIF
          WRITE(25,2401)
          WRITE(25,2411)
        ELSE
          WRITE(25,2750) LakeName
          IF (LakeNum .EQ. 1) THEN
            IF (Ogoki .EQ. 1) THEN
               WRITE(25,3000)
            ELSE
               WRITE(25,3005)
            ENDIF
          ELSE
            WRITE(25,2200)
          ENDIF
          WRITE(25,2401)
          WRITE(25,2411)
        ENDIF

      ENDIF

c
c  Compute the NBS and write it into the output files
c 
      IF (Method .EQ. CompMethod) THEN
         CALL DoCompNBS(LkArea)
      ELSE
         CALL DoResidNBS(LkArea)
      ENDIF

      CLOSE(25)
      PRINT*, 'Finished.'

c
c  Do we want to do another one?
       
      Answer = 'Q'
      DO 50 WHILE ((Answer .NE. 'Y') .AND. (Answer .NE. 'N'))
         PRINT*, 'Do you wish to produce another NBS file?'
         READ(*,1000) Answer
         CALL Caps(Answer, 1)
  50  CONTINUE
      IF (Answer .EQ. 'Y') GOTO 5

c
c FORMATS
c
 1000 FORMAT(A1)
 2200 format(80x)

 2401 FORMAT(3X, 'YEAR', 2X, '     JAN     FEB     MAR     APR',
     &                       '     MAY     JUN     JUL     AUG',
     &                       '     SEP     OCT     NOV     DEC')

 2411 FORMAT(3X, 4('='), 2X, 12(8('=')))     


 2500 FORMAT(' Lake ',A8,' Component Net Basin Supply ', 
     &       '(tenths of mm). Overlake Precipitation was used.')
 2510 FORMAT(' Lake ',A8,' Component Net Basin Supply (CMS). ',
     &       'Overlake Precipitation was used.')
 2600 FORMAT(' Lake ',A8,' Residual Net Basin Supply (tenths of mm).')
 2700 FORMAT(' Lake ',A8,' Component Net Basin Supply ', 
     &       '(tenths of mm). Overland Precipitation was used.')
 2710 FORMAT(' Lake ',A8,' Component Net Basin Supply (CMS). ',
     &       'Overland Precipitation was used.')
 2750 FORMAT(' Lake ',A8,' Residual Net Basin Supply (CMS).')
 3000 FORMAT(' Note that these values DO INCLUDE the Ogoki diversion.')   
 3005 FORMAT(' Note that these values DO NOT include Ogoki diversion.')   
 
      END

c******************************************************************************
      SUBROUTINE Caps(String, Chars)
      IMPLICIT   NONE
      INTEGER    Chars, I
      CHARACTER*(*) String
      
      DO 10, I = 1, Chars
        IF ((String(I:I) .GE. 'a') .AND. (String(I:I) .LE. 'z')) THEN
          String(I:I) = CHAR(ICHAR(String(I:I)) - 32)
        ENDIF
 10   CONTINUE
      RETURN
      END

c******************************************************************************
      SUBROUTINE GetMethod(Method)
      IMPLICIT   NONE
      INTEGER    Method
      CHARACTER*1  M
      
      Method = -1
      DO 10 WHILE ((Method .NE. 1) .AND. (Method .NE. 2))
        WRITE(*, 1000)
        READ(*, 1001) M
        Method=ICHAR(M) - 48
  10  CONTINUE


 1000 FORMAT(/,/,' Please choose the method to use in computing the ',
     &       'Net Basin Supply:', /, 
     &       9X, '1 - Component Method (Precip+Runoff-Evap)', /, 
     &       9X, '2 - Water Balance Method (ChangeInStorage-Inflow',
     &       '+Outflow)', /,
     &       ' Enter numeric value (1 or 2): ')
 1001 FORMAT(A1)
 
      END

c******************************************************************************
      SUBROUTINE GetPrcType(PrcType)
      IMPLICIT   NONE
      INTEGER    PrcType
      CHARACTER*1  P
      
      PrcType = -1
      DO 10 WHILE ((PrcType .NE. 1) .AND. (PrcType .NE. 2))
        WRITE(*, 1000)
        READ(*, 1001) P
        PrcType=ICHAR(P) - 48
  10  CONTINUE


 1000 FORMAT(/,/,' Please choose the type of precipitation to use in ',
     &       'the computations', /, 
     &       9X, '1 - Overlake', /, 
     &       9X, '2 - Overland', /,
     &       ' Enter numeric value (1 or 2): ')
 1001 FORMAT(A1)
 
      END

c******************************************************************************
      SUBROUTINE GetOutputUnits(Units)
      IMPLICIT   NONE
      INTEGER    Units
      CHARACTER*1  U
      
      Units = -1
      DO 10 WHILE ((Units .NE. 1) .AND. (Units .NE. 2))
        WRITE(*, 1000)
        READ(*, 1001) U
        Units=ICHAR(U) - 48
  10  CONTINUE


 1000 FORMAT(/,/,' Please choose the units to use in output file', /, 
     &       9X, '1 - Tenths of millimeters over the lake surface', /, 
     &       9X, '2 - Cubic meters per second', /,
     &       ' Enter numeric value (1 or 2): ')
 1001 FORMAT(A1)
 
      END

c******************************************************************************
      SUBROUTINE GetLakeName(LakeNum, Method)
      IMPLICIT   NONE
      INTEGER    LakeNum, Method, HighNum
      CHARACTER*1  L
      
      IF (Method .EQ. 1) HighNum = 6     ! Component method
      IF (Method .EQ. 2) HighNum = 5     ! Residual method

      LakeNum = -1
      DO 10 WHILE ((LakeNum .LT. 1) .OR. (LakeNum .GT. HighNum))
        IF (HighNum .EQ. 6) WRITE(*, 1000)
        IF (HighNum .EQ. 5) WRITE(*, 1001)
        READ(*, 1005) L
        LakeNum=ICHAR(L) - 48
  10  CONTINUE

      IF ((Method .EQ. 2) .AND. (LakeNum .GE. 3)) 
     &    LakeNum = LakeNum + 1
      IF ((Method .EQ. 2) .AND. (LakeNum .EQ. 2)) LakeNum = 7


 1000 FORMAT(/,/,' Please choose the lake', /, 
     &       9X, '1 - Superior', /, 
     &       9X, '2 - Michigan', /,
     &       9X, '3 - Huron', /,
     &       9X, '4 - St. Clair', /,
     &       9X, '5 - Erie', /,
     &       9X, '6 - Ontario', /,
     &       ' Enter numeric value (1 to 6): ')
 1001 FORMAT(/,/,' Please choose the lake', /, 
     &       9X, '1 - Superior', /, 
     &       9X, '2 - Michigan-Huron', /,
     &       9X, '3 - St. Clair', /,
     &       9X, '4 - Erie', /,
     &       9X, '5 - Ontario', /,
     &       ' Enter numeric value (1 to 5): ')
 1005 FORMAT(A1)
 
      END

c******************************************************************************
      SUBROUTINE GetOgoki(Ogoki)
      IMPLICIT   NONE
      INTEGER    Ogoki
      CHARACTER*1  YN
      
      Ogoki = -1
      DO 10 WHILE ((Ogoki .NE. 1) .AND. (Ogoki .NE. 2))
        WRITE(*, 1000)
        READ(*, 1001) YN
        CALL Caps(YN, 1)
        IF (YN .EQ. 'Y') Ogoki = 1
        IF (YN .EQ. 'N') Ogoki = 2
  10  CONTINUE


 1000 FORMAT(/,/,' Do you want to include the Ogoki Diversion in the ',
     &       'inflow value?', /,
     &       ' See the technical report (page 7) if you are unsure.'
     &       ' Enter Y or N: ')
 1001 FORMAT(A1)
 
      END

c******************************************************************************
c  Very simple test of leap year status.  Only valid for years from 1801-2099.
c
      LOGICAL FUNCTION IsLeapYear(Year)
      IMPLICIT  NONE
      INTEGER   Year, I

      IF (Year .EQ. 1900) THEN
        IsLeapYear = .FALSE.
        RETURN
      ENDIF
      IF (Year .EQ. (Year/4)*4) THEN
        IsLeapYear = .TRUE.
        RETURN
      ENDIF
      IsLeapYear = .FALSE.
      RETURN

      END

c******************************************************************************
      SUBROUTINE  DoCompNBS(LakeArea)
      IMPLICIT    NONE

      INTEGER     SYr, EYr
      PARAMETER   (SYr = 1948)
      PARAMETER   (EYr = 1995)

      INTEGER     OverLake, OverLand
      PARAMETER   (OverLake = 1)
      PARAMETER   (OverLand = 2)

      INTEGER     Centimeters, CubicMeters
      PARAMETER   (Centimeters = 1)
      PARAMETER   (CubicMeters = 2)

      INTEGER     PrcType, Units, NameLen, StartYr, EndYr, Ogoki,
     &            I, IOS, Year, Dy_Mon(12), Seconds
      LOGICAL     IsLeapYear
      REAL*4      Precip(SYr:EYr, 12), Prc(12),
     &            Runoff(SYr:EYr, 12), Run(12),
     &            Evap(SYr:EYr, 12), Evp(12),
     &            NBS(SYr:EYr, 12), LakeArea
      CHARACTER*8 LakeName

      DATA Dy_Mon /31,28,31,30,31,30,31,31,30,31,30,31/

      COMMON /Options/ PrcType, Units, LakeName, NameLen, Ogoki,
     &                 StartYr, EndYr

      DO 10, Year = StartYr, EndYr
        DO 9, I = 1, 12
           Precip(Year,I) = -99.99
           Runoff(Year,I) = -99.99
           Evap(Year,I)   = -99.99
           NBS(Year,I) = -999.9
    9   CONTINUE
   10 CONTINUE

      IF ( PrcType .EQ. OverLake ) THEN
        OPEN(UNIT=11, FILE=LakeName(1:NameLen)//'.PLK', STATUS='OLD')
      ELSE
        OPEN(UNIT=11, FILE=LakeName(1:NameLen)//'.PLD', STATUS='OLD')
      ENDIF

      OPEN(UNIT=12, FILE=LakeName(1:NameLen)//'.RUN', STATUS='OLD')
      OPEN(UNIT=13, FILE=LakeName(1:NameLen)//'.EVP', STATUS='OLD')

c
c  Skip the header lines
c
      DO 20, I = 1, 4
         READ(11, 2000) 
         READ(12, 2000)
         READ(13, 2000)        
  20  CONTINUE
      
c      
c  READ input data
c
      READ(11, 2000, IOSTAT=IOS) Year, (Prc(I), I=1,12)  ! Reading data into an array.
      DO 50 WHILE (IOS .EQ. 0)
        IF ((Year .GE. StartYr) .AND. (Year .LE. EndYr)) THEN
          DO 45, I = 1, 12
            Precip(Year,I) = Prc(I)
  45      CONTINUE
        ENDIF
        READ(11, 2000, IOSTAT=IOS) Year, (Prc(I), I=1,12)
  50  CONTINUE
      CLOSE(11)

      READ(12, 2000, IOSTAT=IOS) Year, (Run(I), I=1,12)  ! Reading data into an array.
      DO 70 WHILE (IOS .EQ. 0)
        IF ((Year .GE. StartYr) .AND. (Year .LE. EndYr)) THEN
          DO 65, I = 1, 12
            Runoff(Year,I) = Run(I)
  65      CONTINUE
        ENDIF
        READ(12, 2000, IOSTAT=IOS) Year, (Run(I), I=1,12)
  70  CONTINUE
      CLOSE(12)

      READ(13, 2000, IOSTAT=IOS) Year, (Evp(I), I=1,12)  ! Reading data into an array.
      DO 90 WHILE (IOS .EQ. 0)
        IF ((Year .GE. StartYr) .AND. (Year .LE. EndYr)) THEN
          DO 85, I = 1, 12
            Evap(Year,I) = Evp(I)
  85      CONTINUE
        ENDIF
        READ(13, 2000, IOSTAT=IOS) Year, (Evp(I), I=1,12)
  90  CONTINUE
      CLOSE(13)

c
c  Compute the NBS values in tenths of mm over the lake
c
      DO 125, Year = StartYr, EndYr
        DO 120, I = 1, 12
           NBS(Year,I) = -9999.
           IF (Precip(Year,I) .LT. -99.98) GOTO 120
           IF (Runoff(Year,I) .LT. -99.98) GOTO 120
           IF (Evap(Year,I)   .LT. -99.98) GOTO 120
           NBS(Year,I) = (Precip(Year,I) + Runoff(Year,I) -
     &           Evap(Year,I))
 120    CONTINUE
 125  CONTINUE 

c
c  If necessary, convert from tenths of mm over the lake to cms
c
      IF (Units .EQ. CubicMeters) THEN
        DO 175, Year=StartYr, EndYr
          Dy_Mon(2) = 28
          IF (IsLeapYear(Year)) Dy_Mon(2) = 29
          DO 170, I=1,12
            Seconds = 86400 * Dy_Mon(I)
            NBS(Year,I)= (NBS(Year,I)/10000)*LakeArea / Seconds
 170      CONTINUE
 175    CONTINUE
      ENDIF

c
c Writing to the output file.  Units are either tenths of mm over the 
c lake surface or cubic meters per second.
c 
      DO 200, Year= StartYr,EndYr
        WRITE(25, 1200) Year, ( NBS(Year,I), I=1,12 ) 
 200  CONTINUE

c
c  FORMATs
c
 1200 FORMAT(3X, I4, 2X, 12I8) 
 2000 FORMAT(2X, I4, 12F6.0)

      END

c******************************************************************************
      SUBROUTINE  DoResidNBS(LakeArea)
      IMPLICIT    NONE

      INTEGER     SYr, EYr
      PARAMETER   (SYr = 1948)
      PARAMETER   (EYr = 1995)

      INTEGER     OverLake, OverLand
      PARAMETER   (OverLake = 1)
      PARAMETER   (OverLand = 2)

      INTEGER     Centimeters, CubicMeters
      PARAMETER   (Centimeters = 1)
      PARAMETER   (CubicMeters = 2)

      INTEGER     PrcType, Units, NameLen, StartYr, EndYr, Ogoki,
     &            I, J, U, IOS, Year, In2Out, Last, Dy_Mon(12),
     &            Seconds
      LOGICAL     IsLeapYear
      REAL*4      Inflow(SYr:EYr,12), Outflow(SYr:EYr,12)
      REAL*4      CIS(SYr:EYr,12), Dat(12)
      REAL*4      NBS(SYr:EYr, 12), LakeArea

      CHARACTER*8 LakeName

      DATA Dy_Mon /31,28,31,30,31,30,31,31,30,31,30,31/

      COMMON /Options/ PrcType, Units, LakeName, NameLen, Ogoki,
     &                 StartYr, EndYr


      DO 5, Year = StartYr, EndYr
        DO 4, I = 1, 12
           Inflow(Year,I)  = 0.
           Outflow(Year,I) = 0.
           NBS(Year,I) = -999.9
   4    CONTINUE
   5  CONTINUE

      IF (LakeName .EQ. 'Superior') THEN
         OPEN(UNIT=11, FILE='SUPERIOR.CIS', STATUS='OLD')
         IF (Ogoki .EQ. 1) THEN
            OPEN(UNIT=12, FILE='LLAKOGOK.FLW', STATUS='OLD')
         ELSE
            OPEN(UNIT=12, FILE='LONGLAKE.FLW', STATUS='OLD')
         ENDIF
         OPEN(UNIT=13, FILE='STMARYS.FLW',  STATUS='OLD')
         Last = 13
         In2Out = 13
      ELSE IF (LakeName .EQ. 'Mich-Hur') THEN
         OPEN(UNIT=11, FILE='MICH-HUR.CIS', STATUS='OLD')
         OPEN(UNIT=12, FILE='STMARYS.FLW',  STATUS='OLD')
         OPEN(UNIT=13, FILE='STCRIVR.FLW',  STATUS='OLD')
         OPEN(UNIT=14, FILE='CHICAGO.FLW',  STATUS='OLD')
         Last = 14
         In2Out = 13
      ELSE IF (LakeName .EQ. 'StClair ') THEN
         OPEN(UNIT=11, FILE='STCLAIR.CIS', STATUS='OLD')
         OPEN(UNIT=12, FILE='STCRIVR.FLW', STATUS='OLD')
         OPEN(UNIT=13, FILE='DETROIT.FLW', STATUS='OLD')
         Last = 13
         In2Out = 13
      ELSE IF (LakeName .EQ. 'Erie    ') THEN
         OPEN(UNIT=11, FILE='ERIE.CIS',    STATUS='OLD')
         OPEN(UNIT=12, FILE='DETROIT.FLW', STATUS='OLD')
         OPEN(UNIT=13, FILE='WELLAND.FLW', STATUS='OLD')
         OPEN(UNIT=14, FILE='NIAGARA.FLW', STATUS='OLD')
         Last = 14
         In2Out = 13
      ELSE IF (LakeName .EQ. 'Ontario ') THEN
         OPEN(UNIT=11, FILE='ONTARIO.CIS', STATUS='OLD')
         OPEN(UNIT=12, FILE='NIAGARA.FLW', STATUS='OLD')
         OPEN(UNIT=13, FILE='WELLAND.FLW', STATUS='OLD')
         OPEN(UNIT=14, FILE='STLAWRN.FLW', STATUS='OLD')
         Last = 14
         In2Out = 14
      ELSE
         Last = 0
         In2Out = 0
         PRINT*, 'Invalid lake name in DoResidNBS() :', LakeName
         CALL EXIT(1)
      ENDIF
      
c
c  Skip header lines in input files
c
      DO 10, I = 11, Last
        DO 8, J = 1, 4
          READ(I, *)
   8    CONTINUE
  10  CONTINUE 

c
c  Read Change in Storage data file
c
      READ(11, 2000, IOSTAT=IOS) Year, (Dat(I), I=1,12)
      DO 25 WHILE (IOS .EQ. 0)
        IF ((Year .GE. StartYr) .AND. (Year .LE. EndYr)) THEN
          DO 20, I = 1, 12
            CIS(Year,I) = Dat(I)
  20      CONTINUE
        ENDIF
        READ(11, 2000, IOSTAT=IOS) Year, (Dat(I), I=1,12)
  25  CONTINUE
      CLOSE(11)

c
c  Read Inflow data files.
c
      DO 50, U = 12, In2Out-1
        READ(U, 2000, IOSTAT=IOS) Year, (Dat(I), I=1,12)
        DO 45 WHILE (IOS .EQ. 0)
          IF ((Year .GE. StartYr) .AND. (Year .LE. EndYr)) THEN
            DO 40, I = 1, 12
              Inflow(Year,I) = Inflow(Year,I) + Dat(I)
  40        CONTINUE
          ENDIF
          READ(U, 2000, IOSTAT=IOS) Year, (Dat(I), I=1,12)
  45    CONTINUE
        CLOSE(U)
  50  CONTINUE

c
c  Read Outflow data files.
c
      DO 90, U = In2Out, Last
        READ(U, 2000, IOSTAT=IOS) Year, (Dat(I), I=1,12)
        DO 85 WHILE (IOS .EQ. 0)
          IF ((Year .GE. StartYr) .AND. (Year .LE. EndYr)) THEN
            DO 80, I = 1, 12
              Outflow(Year,I) = Outflow(Year,I) + Dat(I)
  80        CONTINUE
          ENDIF
          READ(U, 2000, IOSTAT=IOS) Year, (Dat(I), I=1,12)
  85    CONTINUE
        CLOSE(U)
  90  CONTINUE

c
c  Computing the Net Basin Supply ===>> Water Balance Method.
c  At this point it is in cubic meters per second.
c
      DO 120, Year = StartYr, EndYr
        DO 110, I = 1,12
           NBS(Year,I) = CIS(Year,I)-Inflow(Year,I)+Outflow(Year,I)
 110    CONTINUE
 120  CONTINUE

c
c  Convert to tenths of millimeters over the lake, if necessary
c
      IF (Units .EQ. Centimeters) THEN
        DO 150, Year = StartYr, EndYr
          Dy_Mon(2) = 28
          IF (IsLeapYear(Year)) Dy_Mon(2) = 29
          DO 140, I = 1,12
            Seconds = 86400 * Dy_Mon(I)
            NBS(Year,I) = ((NBS(Year,I)*Seconds) / LakeArea) * 10000    ! CMS -> mm*10
 140      CONTINUE
 150    CONTINUE
      ENDIF          

c
c***********************************************************************      
c
c  WRITE the output file.  
c
      DO 200, Year = StartYr, EndYr
         WRITE(25, 2500) Year, ((NBS(Year,I)),I = 1, 12)
 200  CONTINUE
       
c
c  FORMATs
c
 2000 FORMAT(2X, I4, 12F6.0)
 2500 FORMAT(3X, I4, 2X, 12I8)    

      END
